<?php
namespace HotellerElementor;

use HotellerElementor\Widgets\Hoteller_Navigation_Menu;
use HotellerElementor\Widgets\Hoteller_Blog_Posts;
use HotellerElementor\Widgets\Hoteller_Gallery_Grid;
use HotellerElementor\Widgets\Hoteller_Gallery_Masonry;
use HotellerElementor\Widgets\Hoteller_Gallery_Justified;
use HotellerElementor\Widgets\Hoteller_Gallery_Horizontal;
use HotellerElementor\Widgets\Hoteller_Album_Grid;
use HotellerElementor\Widgets\Hoteller_Distortion_Grid;
use HotellerElementor\Widgets\Hoteller_Slider_Horizontal;
use HotellerElementor\Widgets\Hoteller_Timeline;
use HotellerElementor\Widgets\Hoteller_Accommodation_Types;
use HotellerElementor\Widgets\Hoteller_Accommodation_Carousel;
use HotellerElementor\Widgets\Hoteller_Slider_Property_Clip;
use HotellerElementor\Widgets\Hoteller_Slider_Zoom;
use HotellerElementor\Widgets\Hoteller_Slider_Parallax;
use HotellerElementor\Widgets\Hoteller_Booking_History;
use HotellerElementor\Widgets\Hoteller_Availability_Search;
use HotellerElementor\Widgets\Hoteller_Availability_Calendar;
use HotellerElementor\Widgets\Hoteller_Mouse_Drive_Vertical_Carousel;
use HotellerElementor\Widgets\Hoteller_Slider_Synchronized_Carousel;
use HotellerElementor\Widgets\Hoteller_Flip_Box;
use HotellerElementor\Widgets\Hoteller_Animated_Text;
use HotellerElementor\Widgets\Hoteller_Animated_Headline;
use HotellerElementor\Widgets\Hoteller_Service_Grid;
use HotellerElementor\Widgets\Hoteller_Service_Carousel;
use HotellerElementor\Widgets\Hoteller_Testimonial_Carousel;
use HotellerElementor\Widgets\Hoteller_Food_Menu;
use HotellerElementor\Widgets\Hoteller_Testimonial_Slider;
use HotellerElementor\Widgets\Hoteller_Portfolio_Timeline;
use HotellerElementor\Widgets\Hoteller_Contact_Form;
use HotellerElementor\Widgets\Hoteller_Search;
use HotellerElementor\Widgets\Hoteller_Background_Menu_Effect;
use HotellerElementor\Widgets\Hoteller_Slider_Image_Carousel;
use HotellerElementor\Widgets\Hoteller_Room_Slider;


// If this file is called directly, abort.
if (!defined('WPINC')) {
    die();
}

/**
 * Main Plugin Class
 *
 * Register new elementor widget.
 *
 * @since 1.0.0
 */
class Hoteller_Elementor {
    
    /**
     * Plugin Version
     */
    const VERSION = '1.2.0';

    /**
     * Constructor
     *
     * @since 1.0.0
     *
     * @access public
     */
    public function __construct() {
        $this->add_actions();
        
        add_action('init', array($this, 'init'), -999);
    }

    /**
     * Add Actions
     *
     * @since 1.0.0
     *
     * @access private
     */
    private function add_actions() {
        add_action('elementor/init', [$this, 'on_elementor_init']);
        add_action('elementor/widgets/register', [$this, 'on_widgets_registered']);

        // Enqueue javascript files
        add_action('elementor/frontend/after_register_scripts', [$this, 'register_frontend_scripts']);
        
        // Enqueue CSS style files
        add_action('elementor/frontend/after_enqueue_styles', [$this, 'register_frontend_styles']);
        
        // Enqueue component-specific styles and scripts when needed
        add_action('elementor/frontend/before_render', [$this, 'before_render']);

        //  NUEVO: Incluir estilos personalizados en el editor
    add_action('elementor/editor/after_enqueue_styles', [$this, 'enqueue_editor_styles']);
    }
    
    /**
     * Register frontend scripts
     *
     * @since 1.1.0
     *
     * @access public
     */
    public function register_frontend_scripts() {
        // Check if enable lazy load image
        wp_enqueue_script('masonry');
        wp_enqueue_script('lazy', plugins_url('/hoteller-elementor/assets/js/jquery.lazy.js'), ['jquery'], self::VERSION, true);    
        wp_enqueue_script('modulobox', plugins_url('/hoteller-elementor/assets/js/modulobox.js'), ['jquery'], self::VERSION, true);
        wp_enqueue_script('parallax-scroll', plugins_url('/hoteller-elementor/assets/js/jquery.parallax-scroll.js'), ['jquery'], self::VERSION, true);
        wp_enqueue_script('smoove', plugins_url('/hoteller-elementor/assets/js/jquery.smoove.js'), ['jquery'], self::VERSION, true);
        wp_enqueue_script('parallax', plugins_url('/hoteller-elementor/assets/js/parallax.js'), ['jquery'], self::VERSION, true);
        wp_enqueue_script('blast', plugins_url('/hoteller-elementor/assets/js/jquery.blast.js'), ['jquery'], self::VERSION, true);
        wp_enqueue_script('visible', plugins_url('/hoteller-elementor/assets/js/jquery.visible.js'), ['jquery'], self::VERSION, true);
        
        // Add parallax script effect
        wp_enqueue_script('jarallax', plugins_url().'/hoteller-elementor/assets/js/jarallax.js', ['jquery'], self::VERSION, true);
        
        // Registered scripts
        wp_register_script('anime', plugins_url('/hoteller-elementor/assets/js/anime.min.js'), ['jquery'], self::VERSION, true);
        wp_register_script('hover', plugins_url('/hoteller-elementor/assets/js/hover.js'), ['jquery'], self::VERSION, true);
        wp_register_script('tweenmax', plugins_url('/hoteller-elementor/assets/js/TweenMax.js'), ['jquery'], self::VERSION, true);
        wp_register_script('three', plugins_url('/hoteller-elementor/assets/js/three.min.js'), ['jquery'], self::VERSION, true);
        wp_register_script('flickity', plugins_url('/hoteller-elementor/assets/js/flickity.pkgd.js'), ['jquery'], self::VERSION, true);
        wp_register_script('tilt', plugins_url('/hoteller-elementor/assets/js/tilt.jquery.js'), ['jquery'], self::VERSION, true);
        wp_register_script('hoteller-album-tilt', plugins_url('/hoteller-elementor/assets/js/album-tilt.js'), ['tilt'], self::VERSION, true);
        wp_register_script('justifiedGallery', plugins_url('/hoteller-elementor/assets/js/justifiedGallery.js'), ['jquery'], self::VERSION, true);
        wp_register_script('sticky-kit', plugins_url('/hoteller-elementor/assets/js/jquery.sticky-kit.min.js'), ['jquery'], self::VERSION, true);
        wp_register_script('momentum-slider', plugins_url('/hoteller-elementor/assets/js/momentum-slider.js'), ['jquery'], self::VERSION, true);
        wp_register_script('animatedheadline', plugins_url('/hoteller-elementor/assets/js/jquery.animatedheadline.js'), ['jquery'], self::VERSION, true);
        wp_register_script('owl-carousel', plugins_url('/hoteller-elementor/assets/js/owl.carousel.min.js'), ['jquery'], self::VERSION, true);
        
        // Register swiper script
        wp_register_script('swiper', plugins_url('/hoteller-elementor/assets/js/swiper.js'), ['jquery'], self::VERSION, true);
        
        // Register hoteller-elementor script with proper dependencies
        wp_register_script('hoteller-elementor', plugins_url('/hoteller-elementor/assets/js/hoteller-elementor.js'), ['jquery', 'sticky-kit'], self::VERSION, true);
        
        $params = [
          'ajaxurl' => esc_url(admin_url('admin-ajax.php')),
          'ajax_nonce' => wp_create_nonce('hoteller-post-contact-nonce'),
        ];
        
        wp_localize_script('hoteller-elementor', 'tgAjax', $params);
        wp_enqueue_script('hoteller-elementor');
    }
    
    /**
     * Register frontend styles
     *
     * @since 1.1.0
     *
     * @access public
     */
    public function register_frontend_styles() {
        wp_enqueue_style('modulobox', plugins_url('/hoteller-elementor/assets/css/modulobox.css'), [], self::VERSION, 'all');
        wp_enqueue_style('swiper', plugins_url('/hoteller-elementor/assets/css/swiper.css'), [], self::VERSION, 'all');
        wp_enqueue_style('animatedheadline', plugins_url('/hoteller-elementor/assets/css/animatedheadline.css'), [], self::VERSION, 'all');
        wp_enqueue_style('justifiedGallery', plugins_url('/hoteller-elementor/assets/css/justifiedGallery.css'), [], self::VERSION, 'all');
        wp_enqueue_style('flickity', plugins_url('/hoteller-elementor/assets/css/flickity.css'), [], self::VERSION, 'all');
        wp_enqueue_style('owl-carousel-theme', plugins_url('/hoteller-elementor/assets/css/owl.theme.default.min.css'), [], self::VERSION, 'all');
        wp_enqueue_style('hoteller-elementor', plugins_url('/hoteller-elementor/assets/css/hoteller-elementor.css'), [], self::VERSION, 'all');
        wp_enqueue_style('hoteller-elementor-responsive', plugins_url('/hoteller-elementor/assets/css/hoteller-elementor-responsive.css'), [], self::VERSION, 'all');
        
        // Register component-specific styles
        wp_register_style('room-slider', plugins_url('/hoteller-elementor/assets/css/room-slider.css'), [], self::VERSION, 'all');
        wp_register_style('room-gallery', plugins_url('/hoteller-elementor/assets/css/room-gallery.css'), [], self::VERSION, 'all');
        
        // Load Font Awesome from CDN
        wp_enqueue_style('font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css', [], '5.15.4', 'all');
    }
    
    /**
     * Before render callback
     * 
     * Used to enqueue styles and scripts based on the widget being rendered
     *
     * @since 1.1.0
     *
     * @access public
     * @param \Elementor\Element_Base $element
     */
    public function before_render($element) {
        $widget_name = $element->get_name();
        
        // Enqueue specific styles and scripts for the Room Slider widget
        if ('hoteller-room-slider' === $widget_name) {
            wp_enqueue_style('room-slider');
            wp_enqueue_script('swiper');
        }
    }
    
    /**
     * Manually init required modules.
     *
     * @return void
     */
    public function init() {
        hoteller_templates_manager()->init();
        $this->register_extension();
    }
    
    /**
     * On Elementor Init
     *
     * @since 1.0.0
     *
     * @access public
     */
    public function on_elementor_init() {
        $this->register_category();
    }

    /**
     * On Widgets Registered
     *
     * @since 1.0.0
     *
     * @access public
     */
    public function on_widgets_registered() {
        $this->includes();
        $this->register_widget();
    }

    /**
     * Includes
     *
     * @since 1.0.0
     *
     * @access private
     */
    private function includes() {
        require __DIR__ . '/widgets/navigation-menu.php';
        require __DIR__ . '/widgets/blog-posts.php';
        require __DIR__ . '/widgets/gallery-grid.php';
        require __DIR__ . '/widgets/gallery-masonry.php';
        require __DIR__ . '/widgets/gallery-justified.php';
        require __DIR__ . '/widgets/gallery-horizontal.php';
        require __DIR__ . '/widgets/album-grid.php';
        require __DIR__ . '/widgets/distortion-grid.php';
        require __DIR__ . '/widgets/slider-horizontal.php';
        require __DIR__ . '/widgets/timeline.php';
        require __DIR__ . '/widgets/accommodation-types.php';
        require __DIR__ . '/widgets/accommodation-carousel.php';
        require __DIR__ . '/widgets/slider-property-clip.php';
        require __DIR__ . '/widgets/slider-zoom.php';
        require __DIR__ . '/widgets/slider-parallax.php';
        require __DIR__ . '/widgets/booking-history.php';
        require __DIR__ . '/widgets/availability-search.php';
        require __DIR__ . '/widgets/availability-calendar.php';
        require __DIR__ . '/widgets/mouse-driven-vertical-carousel.php';
        require __DIR__ . '/widgets/slider-synchronized-carousel.php';
        require __DIR__ . '/widgets/flip-box.php';
        require __DIR__ . '/widgets/animated-text.php';
        require __DIR__ . '/widgets/animated-headline.php';
        require __DIR__ . '/widgets/service-grid.php';
        require __DIR__ . '/widgets/service-carousel.php';
        require __DIR__ . '/widgets/testimonial-carousel.php';
        require __DIR__ . '/widgets/testimonial-slider.php';
        require __DIR__ . '/widgets/food-menu.php';
        require __DIR__ . '/widgets/portfolio-timeline.php';
        require __DIR__ . '/widgets/contact-form.php';
        require __DIR__ . '/widgets/search.php';
        require __DIR__ . '/widgets/background-menu-effect.php';
        require __DIR__ . '/widgets/slider-image-carousel.php';
        require __DIR__ . '/widgets/room-slider.php';
    }
    
    /**
     * Register Category
     *
     * @since 1.0.0
     *
     * @access private
     */
    private function register_category() {
        \Elementor\Plugin::instance()->elements_manager->add_category(
            'hoteller-theme-widgets-category-fullscreen',
            [
                'title' => 'Theme Fullscreen Elements',
                'icon'  => 'fonts',
            ],
            1
        );
        
        \Elementor\Plugin::instance()->elements_manager->add_category(
            'hoteller-theme-widgets-category',
            [
                'title' => 'Theme General Elements',
                'icon'  => 'fonts',
            ],
            2
        );
    }

    /**
     * Register Widget
     *
     * @since 1.0.0
     *
     * @access private
     */
    private function register_widget() {
        // Register all widgets using the same method for consistency
        $widgets = [
            new Hoteller_Navigation_Menu(),
            new Hoteller_Slider_Property_Clip(),
            new Hoteller_Slider_Zoom(),
            new Hoteller_Slider_Parallax(),
            new Hoteller_Slider_Horizontal(),
            new Hoteller_Accommodation_Types(),
            new Hoteller_Accommodation_Carousel(),
            new Hoteller_Booking_History(),
            new Hoteller_Timeline(),
            new Hoteller_Distortion_Grid(),
            new Hoteller_Blog_Posts(),
            new Hoteller_Gallery_Grid(),
            new Hoteller_Gallery_Masonry(),
            new Hoteller_Gallery_Justified(),
            new Hoteller_Gallery_Horizontal(),
            new Hoteller_Album_Grid(),
            new Hoteller_Availability_Search(),
            new Hoteller_Availability_Calendar(),
            new Hoteller_Mouse_Drive_Vertical_Carousel(),
            new Hoteller_Slider_Synchronized_Carousel(),
            new Hoteller_Flip_Box(),
            new Hoteller_Animated_Text(),
            new Hoteller_Animated_Headline(),
            new Hoteller_Service_Grid(),
            new Hoteller_Service_Carousel(),
            new Hoteller_Testimonial_Carousel(),
            new Hoteller_Testimonial_Slider(),
            new Hoteller_Food_Menu(),
            new Hoteller_Portfolio_Timeline(),
            new Hoteller_Contact_Form(),
            new Hoteller_Search(),
            new Hoteller_Background_Menu_Effect(),
            new Hoteller_Slider_Image_Carousel(),
            new Hoteller_Room_Slider(),
        ];
        
        // Register each widget
        foreach ($widgets as $widget) {
            \Elementor\Plugin::instance()->widgets_manager->register($widget);
        }
    }
    
    /**
     * Register Extension
     *
     * @since 1.0.0
     *
     * @access private
     */
    private function register_extension() {
        // Custom Elementor extensions
        require __DIR__ . '/extensions.php';
        
        hoteller_ext()->init();
    }

    /**
 * Enqueue styles for Elementor editor (so styles like room-slider.css appear inside the builder)
 *
 * @since 1.2.1
 */
public function enqueue_editor_styles() {
    wp_register_style('room-slider', plugins_url('/hoteller-elementor/assets/css/room-slider.css'), [], self::VERSION, 'all');
    wp_enqueue_style('room-slider');
}
}

new Hoteller_Elementor();