<?php
/**
 * Room Slider Template Style 1 (Moderm)
 * Mi Hoteller Personalizado
 */

if (!defined('ABSPATH')) {
    exit;
}

$settings = $this->get_settings_for_display();
$slider_id = 'room-slider-' . uniqid();

$autoplay = $settings['autoplay'] === 'yes' ? 'true' : 'false';
$autoplay_speed = absint($settings['autoplay_speed'] ?? 5000);
$show_description = $settings['show_description'] === 'yes';
$description_length = absint($settings['description_length'] ?? 120);
$show_amenities = $settings['show_amenities'] === 'yes';
$show_price = $settings['show_price'] === 'yes';
$show_custom_text = $settings['show_custom_text'] === 'yes';
$custom_text_below_price = $settings['custom_text_below_price'] ?? '';
$image_size = $settings['image_size'] ?? 'large';
?>

<div class="room-slider style1" id="<?php echo esc_attr($slider_id); ?>">
    <div class="swiper-container">
        <div class="swiper-wrapper">
            <?php while ($rooms->have_posts()) : $rooms->the_post();
                $room_id = get_the_ID();
                $title = get_the_title();
                $permalink = get_permalink();
                $thumbnail_id = get_post_thumbnail_id();
                $image_url = wp_get_attachment_image_url($thumbnail_id, $image_size);

                $room_type = null;
                if (class_exists('MPHB') && method_exists('MPHB', 'getRoomTypeRepository')) {
                    $room_type = MPHB()->getRoomTypeRepository()->findById($room_id);
                }

                // Descripción
                $description = '';
                if ($show_description) {
                    $description = get_the_excerpt();
                    if (empty($description)) {
                        $description = get_the_content();
                    }
                    $description = wp_strip_all_tags($description);
                    $description = wp_trim_words($description, $description_length, '...');
                }

                // Amenidades
                $amenities = [];
                if ($show_amenities) {
                    $terms = get_the_terms($room_id, 'mphb_room_type_facility');
                    if (!empty($terms) && !is_wp_error($terms)) {
                        $amenities = $terms;
                    }
                }
            ?>
            <div class="swiper-slide">
                <div class="room_slide_wrapper">
                    <div class="room_slide_content">
                        <h3 class="room_slide_title">
                            <a href="<?php echo esc_url($permalink); ?>"><?php echo esc_html($title); ?></a>
                        </h3>

                        <?php if (!empty($description)) : ?>
                            <div class="room_slide_excerpt">
                                <?php echo esc_html($description); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (!empty($amenities)) : ?>
                            <div class="room_amenities">
                                <div class="amenities-list">
                                    <?php foreach ($amenities as $amenity) :
                                        $slug = strtolower(trim($amenity->slug));
                                        $icons = [
                                            'air-conditioning' => 'fas fa-snowflake',
                                            'wifi' => 'fas fa-wifi',
                                            'tv' => 'fas fa-tv',
                                            'hot-shower' => 'fas fa-bath',
                                            'terrace' => 'fas fa-door-open',
                                            'private-bathroom' => 'fas fa-bath',
                                            'two-double-beds' => 'fas fa-bed',
                                            'cable-tv' => 'fas fa-tv',
                                            'safe' => 'fas fa-lock',
                                            'fan' => 'fas fa-wind',
                                            'hair-dryer' => 'fas fa-blender',
                                            'sun-chairs' => 'fas fa-chair',
                                            'equipped-kitchen' => 'fas fa-utensils',
                                            'private-swimming-pool' => 'fas fa-swimmer',
                                            'high-speed-wifi' => 'fas fa-wifi'
                                        ];
                                        $icon_class = $icons[$slug] ?? 'fas fa-check';
                                    ?>
                                        <div class="amenity-item">
                                            <i class="<?php echo esc_attr($icon_class); ?>"></i>
                                            <?php echo esc_html($amenity->name); ?>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                        <?php endif; ?>

                        <?php if ($show_price): ?>
                            <div class="room_slide_price">
                                <span class="mphb-price">
                                    <?php
                                    $custom_price = get_post_meta($room_id, 'custom_pricing', true);
                                    if (!empty($custom_price)) {
                                        echo esc_html($custom_price);
                                    } elseif (function_exists('mphb_tmpl_the_room_type_default_price')) {
                                        ob_start();
                                        mphb_tmpl_the_room_type_default_price($room_id);
                                        $default_price = trim(ob_get_clean());
                                        echo !empty($default_price) ? $default_price : esc_html__('$0', 'hoteller-elementor');
                                    }
                                    ?>
                                </span>

                                <?php if ($show_custom_text && !empty($custom_text_below_price)) : ?>
                                    <span class="mphb-price-period"><?php echo esc_html($custom_text_below_price); ?></span>
                                <?php else : ?>
                                    <span class="mphb-price-period"><?php esc_html_e('per night', 'hoteller-elementor'); ?></span>
                                <?php endif; ?>
                            </div>
                        <?php endif; ?>

                        <div class="room_slide_action">
                            <a href="<?php echo esc_url($permalink); ?>" class="button">
                                <?php esc_html_e('View Details', 'hoteller-elementor'); ?>
                            </a>
                        </div>
                    </div>

                    <div class="room_slider_gallery">
                        <?php if ($image_url) : ?>
                            <div class="gallery-swiper">
                                <img src="<?php echo esc_url($image_url); ?>" alt="<?php echo esc_attr($title); ?>">
                            </div>
                        <?php else : ?>
                            <div class="no-image-placeholder">
                                <?php esc_html_e('No image available', 'hoteller-elementor'); ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
            <?php endwhile; ?>
        </div>

        <div class="swiper-button-prev"></div>
        <div class="swiper-button-next"></div>
        <div class="swiper-pagination"></div>
    </div>
</div>

<script>
jQuery(document).ready(function($) {
    new Swiper('#<?php echo esc_attr($slider_id); ?> .swiper-container', {
        slidesPerView: 1,
        spaceBetween: 30,
        loop: true,
        autoplay: <?php echo $autoplay; ?> ? {
            delay: <?php echo $autoplay_speed; ?>,
            disableOnInteraction: false
        } : false,
        speed: 800,
        navigation: {
            nextEl: '#<?php echo esc_attr($slider_id); ?> .swiper-button-next',
            prevEl: '#<?php echo esc_attr($slider_id); ?> .swiper-button-prev'
        },
        pagination: {
            el: '#<?php echo esc_attr($slider_id); ?> .swiper-pagination',
            clickable: true
        }
    });
});
</script>