<?php
/**
 * Room Slider Template Style 3
 * Mi Hoteller Personalizado
 */

if (!defined('ABSPATH')) {
    exit;
}

// Aumentar el lmite de memoria temporalmente si es necesario
if (ini_get('memory_limit') < 128 * 1024 * 1024) {
    ini_set('memory_limit', '128M');
}

$settings = $this->get_settings_for_display();
$room_id = null;

// Asegurarnos de que specific_rooms existe y es un array o contiene datos vlidos
if (!empty($settings['specific_rooms'])) {
    if (is_array($settings['specific_rooms']) && !empty($settings['specific_rooms'])) {
        $room_id = intval($settings['specific_rooms'][0]); // Solo se muestra una habitacin
    } elseif (is_string($settings['specific_rooms']) || is_numeric($settings['specific_rooms'])) {
        // Si es un string o nmero, convertir directamente
        $room_id = intval($settings['specific_rooms']);
    }
}

// Si an no tenemos un room_id vlido pero tenemos un objeto $rooms, usamos el primero
if (empty($room_id) && isset($rooms) && $rooms->have_posts()) {
    $rooms->the_post();
    $room_id = get_the_ID();
    // Reiniciamos el query para no afectar a otros estilos si se cambia despus
    $rooms->rewind_posts();
}

$image_size = $settings['image_size'] ?? 'large';
$show_description = isset($settings['show_description']) && $settings['show_description'] === 'yes';
$description_length = absint($settings['description_length'] ?? 120);
$show_amenities = isset($settings['show_amenities']) && $settings['show_amenities'] === 'yes';
$show_price = isset($settings['show_price']) && $settings['show_price'] === 'yes';
$show_custom_text = isset($settings['show_custom_text']) && $settings['show_custom_text'] === 'yes';
$custom_text_below_price = $settings['custom_text_below_price'] ?? '';

if (!$room_id) {
    echo '<div class="room-slider-error">' . esc_html__('No room selected for Style 3. Please select a specific room when using this style.', 'hoteller-elementor') . '</div>';
    return;
}

// Verificamos si el post existe y es del tipo correcto - usando get_post una sola vez
$post = get_post($room_id);
if (!$post || $post->post_type !== 'mphb_room_type') {
    echo '<div class="room-slider-error">' . esc_html__('Invalid room selected.', 'hoteller-elementor') . '</div>';
    return;
}

$slider_id = 'room-style3-' . uniqid();
$title = $post->post_title; // Usar directamente del objeto post
$permalink = get_permalink($room_id);

// Descripcin - solo procesar si es necesario
$description = '';
if ($show_description) {
    $excerpt = $post->post_excerpt; // Obtener del objeto post
    if (!empty($excerpt)) {
        $description = $excerpt;
    } else {
        $content = $post->post_content; // Obtener del objeto post
        $description = wp_strip_all_tags($content);
    }
    
    // Solo aplicar wp_trim_words si realmente es necesario
    if (strlen($description) > $description_length * 5) {
        $description = wp_trim_words($description, $description_length, '...');
    }
}

// Usar los datos precargados de amenidades si estn disponibles
$amenities = [];
if ($show_amenities) {
    if (isset($amenities_by_room) && isset($amenities_by_room[$room_id])) {
        $amenities = $amenities_by_room[$room_id];
    } else {
        $terms = get_the_terms($room_id, 'mphb_room_type_facility');
        if (!empty($terms) && !is_wp_error($terms)) {
            $amenities = $terms;
        }
    }
}

// Usar el precio precargado si est disponible
$custom_price = isset($custom_prices[$room_id]) ? $custom_prices[$room_id] : get_post_meta($room_id, 'custom_pricing', true);

// Obtener la galera ms eficientemente
$gallery_ids = [];
$gallery = get_post_meta($room_id, 'mphb_gallery', true);
if (!empty($gallery)) {
    $gallery_ids = explode(',', $gallery);
    // Limitar el nmero de imgenes para evitar problemas de memoria
    if (count($gallery_ids) > 8) {
        $gallery_ids = array_slice($gallery_ids, 0, 8);
    }
}

// Si no hay imgenes en la galera, agregar la imagen destacada
if (empty($gallery_ids)) {
    $thumbnail_id = get_post_thumbnail_id($room_id);
    if ($thumbnail_id) {
        $gallery_ids = array($thumbnail_id);
    }
}

// 01conos por slug - ampliamos la lista
$icons_by_slug = [
    'air-conditioning'      => 'fas fa-snowflake',
    'ceiling-fan'           => 'fas fa-fan',
    'flat-screen-tv'        => 'fas fa-tv',
    'fully-equipped-kitchen'=> 'fas fa-utensils',
    'hairdryer'             => 'fas fa-wind',
    'high-speed-wifi'       => 'fas fa-wifi',
    'private-bathroom'      => 'fas fa-bath',
    'private-pool'          => 'fas fa-swimming-pool',
    'safe-box'              => 'fas fa-lock',
    'sunbathing-chair'      => 'fas fa-chair',
    'cable-tv'              => 'fas fa-tv',
    'coffee-maker'          => 'fas fa-mug-hot',
    'hot-shower'            => 'fas fa-shower',
    'jacuzzi'               => 'fas fa-hot-tub',
    'one-double-bed'        => 'fas fa-bed',
    'refrigerator'          => 'fas fa-ice-cream',
    'wifi'                  => 'fas fa-wifi',
    // A09adimos ms iconos
    'breakfast'             => 'fas fa-coffee',
    'minibar'               => 'fas fa-glass-martini',
    'room-service'          => 'fas fa-concierge-bell',
    'parking'               => 'fas fa-parking',
    'balcony'               => 'fas fa-door-open',
    'sea-view'              => 'fas fa-water',
    'mountain-view'         => 'fas fa-mountain',
    'king-bed'              => 'fas fa-bed',
    'queen-bed'             => 'fas fa-bed'
];

// Optimizaciones para obtener el precio predeterminado
$default_price = null;
if ($show_price && empty($custom_price)) {
    $room_type = null;
    if (class_exists('MPHB') && method_exists('MPHB', 'getRoomTypeRepository')) {
        $room_type = MPHB()->getRoomTypeRepository()->findById($room_id);
        if ($room_type && method_exists($room_type, 'getDefaultPrice')) {
            $default_price = $room_type->getDefaultPrice();
        }
    }
}
?>

<div class="room-slider style3" id="<?php echo esc_attr($slider_id); ?>">
    <div class="swiper-slide">
        <div class="room_slide_wrapper">
            <div class="room_slide_content">
                <h3 class="room_slide_title">
                    <a href="<?php echo esc_url($permalink); ?>"><?php echo esc_html($title); ?></a>
                </h3>

                <?php if (!empty($description)) : ?>
                    <div class="room_slide_excerpt">
                        <?php echo esc_html($description); ?>
                    </div>
                <?php endif; ?>

                <?php if (!empty($amenities)) : ?>
                    <div class="room_amenities">
                        <div class="amenities-list">
                            <?php 
                            $max_amenities = 12; // Mostramos hasta 12 amenidades
                            $amenity_count = 0;
                            
                            foreach ($amenities as $amenity) :
                                if ($amenity_count >= $max_amenities) break;
                                $amenity_count++;
                                
                                $slug = $amenity->slug;
                                $icon_class = isset($icons_by_slug[$slug]) ? $icons_by_slug[$slug] : 'fas fa-check';
                            ?>
                                <div class="amenity-item">
                                    <i class="<?php echo esc_attr($icon_class); ?>"></i>
                                    <?php echo esc_html($amenity->name); ?>
                                </div>
                            <?php endforeach; ?>
                            
                            <?php if (count($amenities) > $max_amenities) : ?>
                                <div class="amenity-item more-amenities">
                                    <a href="<?php echo esc_url($permalink); ?>" title="<?php esc_attr_e('View all amenities', 'hoteller-elementor'); ?>">
                                        <i class="fas fa-plus-circle"></i>
                                        <?php esc_html_e('More', 'hoteller-elementor'); ?>
                                    </a>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                <?php endif; ?>

                <div class="room_slide_price">
                    <?php if ($show_price) : ?>
                        <span class="mphb-price">
                            <?php
                            if (!empty($custom_price)) {
                                echo esc_html($custom_price);
                            } elseif ($default_price && function_exists('mphb_format_price')) {
                                echo mphb_format_price($default_price, ['decimals' => 0]);
                            } elseif (function_exists('mphb_tmpl_the_room_type_default_price')) {
                                ob_start();
                                mphb_tmpl_the_room_type_default_price($room_id);
                                $default_price_output = trim(ob_get_clean());
                                echo !empty($default_price_output) ? $default_price_output : esc_html__('$0', 'hoteller-elementor');
                            }
                            ?>
                        </span>
                    <?php endif; ?>

                    <?php if ($show_custom_text && !empty($custom_text_below_price)) : ?>
                        <span class="mphb-price-period">
                            <?php echo esc_html($custom_text_below_price); ?>
                        </span>
                    <?php else : ?>
                        <span class="mphb-price-period">
                            <?php esc_html_e('', 'hoteller-elementor'); ?>
                        </span>
                    <?php endif; ?>
                </div>
                            
                <div class="room_slide_action">
                    <a href="<?php echo esc_url($permalink); ?>" class="button">
                        <?php esc_html_e('Ver Detalles', 'hoteller-elementor'); ?>
                    </a>
                </div>
            </div>

            <div class="room_slider_gallery">
                <?php if (!empty($gallery_ids)) : ?>
                    <div class="gallery-swiper swiper">
                        <div class="swiper-wrapper">
                            <?php foreach ($gallery_ids as $image_id) :
                                $image_url = wp_get_attachment_image_url($image_id, $image_size);
                                if ($image_url) : ?>
                                    <div class="swiper-slide">
                                        <img src="<?php echo esc_url($image_url); ?>" alt="<?php echo esc_attr($title); ?>" />
                                    </div>
                                <?php endif;
                            endforeach; ?>
                        </div>
                        <div class="swiper-button-prev"></div>
                        <div class="swiper-button-next"></div>
                        <div class="swiper-pagination"></div>
                    </div>
                <?php else : ?>
                    <div class="no-image-placeholder">
                        <?php esc_html_e('No image available', 'hoteller-elementor'); ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<script>
jQuery(document).ready(function($) {
    var swiperElement = document.querySelector('#<?php echo esc_js($slider_id); ?> .gallery-swiper');
    if (swiperElement) {
        new Swiper(swiperElement, {
            slidesPerView: 1,
            loop: true,
            effect: 'fade',
            fadeEffect: { crossFade: true },
            autoplay: {
                delay: 4000,
                disableOnInteraction: false
            },
            navigation: {
                nextEl: '#<?php echo esc_js($slider_id); ?> .swiper-button-next',
                prevEl: '#<?php echo esc_js($slider_id); ?> .swiper-button-prev'
            },
            pagination: {
                el: '#<?php echo esc_js($slider_id); ?> .swiper-pagination',
                clickable: true
            }
        });
    }
});
</script>